@@ -10,15 +10,14 @@ def fibonacci(inp: int) -> list[int]:
     if inp < 0:
         raise ValueError
 
+    ret = [0 for _ in range(inp + 1)]
+
     if inp == 0:
-        return [0]
+        return ret
 
-    if inp == 1:
-        return [0, 1]
+    ret[1] = 1
 
-    ret = [0, 1]
-
-    for _ in range(2, inp + 1):
-        ret.append(ret[-2] + ret[-1])
+    for i in range(2, inp + 1):
+        ret[i] = ret[i - 1] + ret[i - 2]
 
     return ret
